@@ -75,12 +75,12 @@ class LocationInput(BaseDictKey):
             parse_res = urlparse(self.artifact)
             if parse_res.scheme not in ['http', 'https']:
                 errors.append(f'Artifact location must be http link. {self.artifact}')
-        if self.artifact_archival_copy:
-            parse_res = urlparse(self.artifact_archival_copy)
+        if self.artifactArchivalCopy:
+            parse_res = urlparse(self.artifactArchivalCopy)
             if parse_res.scheme not in ['http', 'https']:
                 errors.append(
                     f'Artifact archival copy must be http link. '
-                    f'{self.artifact_archival_copy}'
+                    f'{self.artifactArchivalCopy}'
                 )
         return errors
 
